@@ -202,10 +202,22 @@ void composition_game_start_theme(const gchar* name, int variation, ClutterActor
 
 	printf("Theme '%s' starting. Variation is %d\n",name,variation);
 	already_quitted = FALSE;
+	GError* error = NULL;
+	//Change Background for this theme
+	gchar *background_image_name = g_strdup_printf("%s/themes/%s/background.png",DATA_DIR,name);
+	ClutterActor *background;
+	if(!(background=clutter_texture_new_from_file(background_image_name, &error))){
+	fprintf(stderr, "%s\n",  error->message);
+            g_error_free(error);
+	}
+	g_free(background_image_name);
+
+
 
 	ClutterActor* view;
 	if ((view = jammo_get_actor_by_id("compositiongame-view"))) {
 		handler_for_view_transition = g_signal_connect(view, "transition-completed", G_CALLBACK(view_transition_completed), NULL);
+		g_object_set(view, "background-actor", background, NULL);
 		clutter_actor_show(view);
 	}
 
@@ -213,6 +225,9 @@ void composition_game_start_theme(const gchar* name, int variation, ClutterActor
 	// X is needed bacause it adds
 	current_theme=theme_create(name,variation,only_playing_mode,jammo_get_actor_by_id("composition_game_play")); /*static current_theme */
 
+	//Add samplebuttons and track_views
+	clutter_container_add(CLUTTER_CONTAINER(view), current_theme->container, NULL);
+
 	//Add save_menu icons to and hide save-menu
 	ClutterActor* saving_dialog = jammo_get_actor_by_id("saving-dialog-view");
 	clutter_actor_raise_top(saving_dialog);
