@@ -2,7 +2,7 @@
 #include <clutter/clutter.h>
 #include <string.h>
 
-#include "../configure.h" //e.g. DATA_DIR
+#include "../../configure.h" //e.g. DATA_DIR
 #include "../jammo-sample-button.h"
 #include "../jammo-track-view.h"
 
