@@ -86,7 +86,7 @@ static void jammo_collaboration_pair_composition_add_jammo_sample_button_remote(
 	printf("got theme :'%s', variation: '%d'\n",theme,variation);
 	JammoSampleButton* sample_button = JAMMO_SAMPLE_BUTTON(theme_give_sample_button_for_this_theme_and_variation_for_this_id(theme,variation,loop_id));
 
-	tangle_draggable_actor_set_dragging_enabled(TANGLE_DRAGGABLE_ACTOR(sample_button), FALSE);
+	clutter_actor_meta_set_enabled(CLUTTER_ACTOR_META(tangle_actor_get_action_by_type(CLUTTER_ACTOR(sample_button), TANGLE_TYPE_DRAG_ACTION)), FALSE);
 	jammo_track_view_add_jammo_sample_button(collaboration_pair_composition->priv->peer_track_view, sample_button, slot);
 
 	printf("peer-track used (pointer:'%p')\n",collaboration_pair_composition->priv->peer_track_view);
