@@ -245,12 +245,13 @@ void on_sequencer_stopped_recording(JammoSequencer* sequencer_old, gpointer user
 static gboolean initialization_needed = TRUE;
 
 void singinggame_force_reinit_songs(){
-	if (songs){
+	if (songs){ //songs is static GList
 		g_list_foreach (songs,(GFunc)song_free,NULL);
 		g_list_free(songs);
 	}
 	songs = song_init_songs_from_disk();
 	clutter_actor_hide(jammo_get_actor_by_id("wait"));
+	initialization_needed = TRUE;
 }
 
 static void say_this_too(JammoMentor* mentor, const gchar*speech, gboolean interrupted, gpointer data){
@@ -263,15 +264,25 @@ static void say_this_too(JammoMentor* mentor, const gchar*speech, gboolean inter
 }
 
 
+/*
+This funtion is called when songselection-view is showed (animation stopped).
+If list of loaded songs had changed (initialization_needed==TRUE)
+  previous song-container-widget is cleaned and all new icons are made (and frames for them)
+
+Regardless of initialization_needed: current language are checked, and non-supported icons are dimmed (not disabled)
+
+*/
 
 void singinggame_start_songselection(){
 	printf("Singinggame_start_songselection\n");
 
-	gboolean first_time=initialization_needed; //only once after initialization textures are arrangent
-	initialization_needed=FALSE;
-
 	ClutterActor* container = jammo_get_actor_by_id("songselection-all-songs");
 
+	if (initialization_needed) {
+		clutter_container_foreach(CLUTTER_CONTAINER(container), CLUTTER_CALLBACK(clutter_actor_hide), NULL); //TODO: this should not be needed
+		clutter_container_foreach(CLUTTER_CONTAINER(container), CLUTTER_CALLBACK(clutter_actor_destroy), NULL);
+	}
+
 	gfloat height_of_container=0;
 	const char* selected_language = chum_get_selected_language();
 
@@ -328,7 +339,7 @@ void singinggame_start_songselection(){
 		//printf("fullpath '%s', name_with_pack '%s' \n",song->fullpath,song->name_with_pack);
 		//printf("xoff '%f', yoff '%f',xsize '%f', ysize '%f' \n", song->xoff,  song->yoff, song->x_size, song->y_size);
 
-		if (first_time)
+		if (initialization_needed)
 			{
 			//This is used size, clip, plaze
 			gfloat x_ratio = icon_size / song->x_size;
@@ -353,8 +364,8 @@ void singinggame_start_songselection(){
 
 
 			//Image and frames goes one group
-			ClutterActor* group = clutter_group_new();
-			clutter_container_add_actor (CLUTTER_CONTAINER (group), song->songbutton);
+			ClutterActor* group = tangle_widget_new();
+			tangle_widget_add (TANGLE_WIDGET (group), song->songbutton,NULL);
 
 			//Frames.
 			ClutterColor black = { 0,0,0, 255 };
@@ -364,30 +375,30 @@ void singinggame_start_songselection(){
 			clutter_rectangle_set_border_width(CLUTTER_RECTANGLE(top),2);
 			clutter_actor_set_size (top,icon_size, 2);
 			clutter_actor_set_position (top,column_counter*(icon_size+icon_marginal)+left_marginal , row_counter*(icon_size+icon_marginal)+top_marginal); 
-			clutter_container_add_actor (CLUTTER_CONTAINER (group), top);
+			tangle_widget_add (TANGLE_WIDGET (group), top,NULL);
 
 			ClutterActor* bottom = clutter_rectangle_new_with_color (&black);
 			clutter_rectangle_set_border_color(CLUTTER_RECTANGLE(bottom),&black);
 			clutter_rectangle_set_border_width(CLUTTER_RECTANGLE(bottom),2);
 			clutter_actor_set_size (bottom,icon_size, 2);
 			clutter_actor_set_position (bottom,column_counter*(icon_size+icon_marginal)+left_marginal , row_counter*(icon_size+icon_marginal)+top_marginal+icon_size); 
-			clutter_container_add_actor (CLUTTER_CONTAINER (group), bottom);
+			tangle_widget_add (TANGLE_WIDGET (group), bottom,NULL);
 
 			ClutterActor* left = clutter_rectangle_new_with_color (&black);
 			clutter_rectangle_set_border_color(CLUTTER_RECTANGLE(left),&black);
 			clutter_rectangle_set_border_width(CLUTTER_RECTANGLE(left),2);
 			clutter_actor_set_size (left,2, icon_size);
 			clutter_actor_set_position (left,column_counter*(icon_size+icon_marginal)+left_marginal , row_counter*(icon_size+icon_marginal)+top_marginal); 
-			clutter_container_add_actor (CLUTTER_CONTAINER (group), left);
+			tangle_widget_add (TANGLE_WIDGET (group), left,NULL);
 
 			ClutterActor* right = clutter_rectangle_new_with_color (&black);
 			clutter_rectangle_set_border_color(CLUTTER_RECTANGLE(right),&black);
 			clutter_rectangle_set_border_width(CLUTTER_RECTANGLE(right),2);
 			clutter_actor_set_size (right,2, icon_size);
 			clutter_actor_set_position (right,column_counter*(icon_size+icon_marginal)+left_marginal+icon_size , row_counter*(icon_size+icon_marginal)+top_marginal); 
-			clutter_container_add_actor (CLUTTER_CONTAINER (group), right);
+			tangle_widget_add (TANGLE_WIDGET (group), right,NULL);
 
-			clutter_container_add(CLUTTER_CONTAINER(container), group, NULL);
+			tangle_widget_add(TANGLE_WIDGET(container), group, NULL);
 			}
 
 		//This dim/undim checking is done every time
@@ -434,6 +445,7 @@ void singinggame_start_songselection(){
 	else
 		jammo_mentor_set_idle_speech_with_callback(jammo_mentor_get_default(),"songselection_idle.spx",say_this_too,"songselection_idle_instrument.spx");
 
+	initialization_needed=FALSE;
 }
 
 static gulong handler_for_mentor_say_selected;
