@@ -17,7 +17,7 @@
 
 #include "../../meam/jammo-backing-track.h"
 #include "../../meam/jammo-recording-track.h"
-#include "../configure.h"  /*SONGS_DIR*/
+#include "../../configure.h"  /*SONGS_DIR*/
 #include "../jammo-mentor.h"
 #include "../jammo-cursor.h"
 #include "../jammo-contour-area.h"
