@@ -33,12 +33,17 @@ Right-door will open little.
 Clicked button will move inside cupboard. (over left door, but under right).
 */
 static void animate_icon_to_cupboard(JammoMentor* mentor, const gchar* speech, gboolean interrupted, gpointer button){
+	if (!button)
+		return;
 	int x_for_cupboard = 510;
 	//Cupboard itself
 	ClutterActor* cupboard = clutter_texture_new_from_file("/opt/jammo/cupboard.png", NULL);
 	clutter_actor_set_x(cupboard,x_for_cupboard);
 	clutter_actor_set_y(cupboard,0);
-	tangle_widget_add(TANGLE_WIDGET(clutter_actor_get_parent(CLUTTER_ACTOR(button))), cupboard, NULL);
+	TangleWidget* view=TANGLE_WIDGET(clutter_actor_get_parent(CLUTTER_ACTOR(button)));
+	if (!view)
+		return;
+	tangle_widget_add(view, cupboard, NULL);
 
 	//Left door. this will be closed
 	ClutterActor* cupboard_left = clutter_texture_new_from_file("/opt/jammo/cupboard_leftdoor.png", NULL);
@@ -118,6 +123,30 @@ ClutterActor* theme_give_sample_button_for_this_theme_and_variation_for_this_id(
 	return sample_button;
 }
 
+/* Actor for parameter is soundfamily-container.*/
+static void pause_actors_animation(ClutterActor *actor, gpointer user_data) {
+	//printf("pause\n");
+	GList* children;
+	for (children = tangle_widget_get_children_readonly(TANGLE_WIDGET(actor)); children; children = children->next) {
+		ClutterAnimation* animation = clutter_actor_get_animation (children->data);
+		ClutterTimeline* timeline = clutter_animation_get_timeline(animation);
+		clutter_timeline_pause(CLUTTER_TIMELINE(timeline));
+	}
+}
+
+/* Actor for parameter is soundfamily-container.
+TODO: This can be called when sequencer is playing, and animations start.
+*/
+static void unpause_actors_animation(ClutterActor *actor, gpointer user_data) {
+	//printf("unpause\n");
+	GList* children;
+	for (children = tangle_widget_get_children_readonly(TANGLE_WIDGET(actor)); children; children = children->next) {
+		ClutterAnimation* animation = clutter_actor_get_animation (children->data);
+		ClutterTimeline* timeline = clutter_animation_get_timeline(animation);
+		clutter_timeline_start(CLUTTER_TIMELINE(timeline));
+	}
+}
+
 /*
 This function creates new jammo_sample_button from given parameters and put it to given parent ClutterActor.
 */
@@ -223,6 +252,9 @@ static ClutterActor* create_soundfamily_button(const gchar* theme_name, const gc
 	tangle_widget_add(parent, widget,NULL);
 	clutter_actor_hide(widget);
 
+	//For pausing and unpausing hidden animations
+	g_signal_connect(widget, "hide", G_CALLBACK(pause_actors_animation), NULL);
+	g_signal_connect(widget, "show", G_CALLBACK(unpause_actors_animation), NULL);
 
 	gchar* filename = g_strdup_printf("%s/%s/advanced/%s", THEMES_DIR, theme_name,button_name);
 	ClutterActor *menu_button =  tangle_button_new_with_background_actor(clutter_texture_new_from_file(filename, NULL));
@@ -323,7 +355,18 @@ static void on_sequencer_stopped(JammoSequencer* sequencer, gpointer data) {
 	printf("Sequencer stopped\n");
 	tangle_actor_show(TANGLE_ACTOR(jammo_mentor_get_default()));
 
-	theme_play_all_icon_animations(theme);
+	//Check is any soundfamily visible and start it's animations
+	if (soundfamily[0]) {
+	int i;
+		for (i=0;i<4;i++) {
+			if (CLUTTER_ACTOR_IS_VISIBLE(soundfamily[i])){
+				clutter_actor_hide(soundfamily[i]);
+				clutter_actor_show(soundfamily[i]); //this triggers animations to play
+			}
+		}
+	}
+	else //easy-game
+		theme_play_all_icon_animations(theme);
 
 	jammo_track_view_set_editing_enabled(theme->bottom_track_view, TRUE);
 	if (theme->upper_track_view && !(chum_get_pair_composition())) {
@@ -793,7 +836,9 @@ if (use_two_tracks) y_offset=80;
 	vault = tangle_vault_new(2, TANGLE_TYPE_SCROLLING_ACTOR, scrolling_actor, JAMMO_TYPE_CURSOR, cursor);
 	tangle_signal_connect_vault(texture, "notify::x", G_CALLBACK(on_cursor_notify_x), vault);
 
-
+	//Advanced-game: there are containers for samplebuttons, do not start hidden animations.
+	if (!chum_is_easy_game())
+		theme_stop_all_icon_animations(theme);
 	return theme;
 }
 
