@@ -16,8 +16,7 @@ ClutterActor* communitymenu_group=NULL;
 void communitymenu_goto_startmenu (TangleAction *action, GObject *source, const gchar *trigger, TangleProperties *properties){
 //	tangle_actor_hide_animated(TANGLE_ACTOR(actor));
 	clutter_actor_hide (CLUTTER_ACTOR(communitymenu_group));
-
-	show_startmenu();
+	clutter_actor_show(jammo_get_actor_by_id("startmenu-view"));
 }
 
 gboolean start_communitymenu()
