@@ -24,17 +24,10 @@
 
 //All global vars Jammer uses TODO: remember to sync with g_free after exit (!important).
 
-#define SAMPLE_SIZE 10
-
-#define k_nearest 5 //k nearest
-
 #define BUFFER_SIZE 6
 
 
-static int selectedKitNum = 1; //0-> elec, 1->eth1, 2->eth2, 3->popk  
-
-static int SENSITIVITY = 350; ///how sensitive jammer is TODO: adjust it to current sound latency
-static guint jammerFreq = 250; ///how often jammer reads values and calcs TODO: adjust it to current sound latency
+static int selectedKitNum = 1; //0-> elec, 1->eth1, 2->eth2, 3->popk  etc
 
 static gboolean isJammerPlaying; //do we read accelerometer values? (TRUE/FALSE)
 
@@ -85,7 +78,7 @@ static void playSound(int i){
 		if (i == 0){	
 			jammo_sample_play(jammerSample0);
 			if (isJammerRecording){
-				jammo_editing_track_add_sample(jammer_editing_track, jammerSample0, jammo_sequencer_get_position(jammer_sequencer)+3000000000);
+				jammo_editing_track_add_sample(jammer_editing_track, jammerSample0, jammo_sequencer_get_position(jammer_sequencer));
 			}
 		}else if (i == 1){
 			jammo_sample_play(jammerSample1);
@@ -199,13 +192,16 @@ static int metro(int pointA[BUFFER_SIZE] ){
 }
 
 static int motion_detect(int e, int firsttime){
- ///Training data
+	int sample_size = 10;
+	int k_nearest = 5; //k nearest
+
+///Training data
     //MovemementA training data (face down)
     //int fd[10][BUFFER_SIZE][3];
     //par a: set number
     //par b: movement number
     //par c: position
-    int fd[SAMPLE_SIZE][SAMPLE_SIZE][3];
+    int fd[sample_size][sample_size][3];
     fd[0][0][0] = -18;fd[0][0][1] = -72;fd[0][0][2] = 954;
     fd[0][1][0] = -16;fd[0][1][1] = -79;fd[0][1][2] = 959;
     fd[0][2][0] = -19;fd[0][2][1] = -85;fd[0][2][2] = 944;
@@ -308,7 +304,7 @@ static int motion_detect(int e, int firsttime){
     fd[9][9][0]=-35;fd[9][9][1]= 594;fd[9][9][2]= 443;
     ///end of MovementA training data
     ///MovemementB training data (side up)
-    int su[SAMPLE_SIZE][SAMPLE_SIZE][3];
+    int su[sample_size][sample_size][3];
     su[0][0][0]=-1008;su[0][0][1]= 72;su[0][0][2]= -36;
     su[0][1][0]=-999;su[0][1][1]= 82;su[0][1][2]= -41;
     su[0][2][0]=-990;su[0][2][1]= 99;su[0][2][2]= -44;
@@ -411,7 +407,7 @@ static int motion_detect(int e, int firsttime){
     su[9][9][0]=-540;su[9][9][1]= -344;su[9][9][2]= -58;
     ///end of MovementB training data
     ///MovemementC training data (face up)
-    int fu[SAMPLE_SIZE][SAMPLE_SIZE][3];
+    int fu[sample_size][sample_size][3];
 	   fu[0][0][0]=90; fu[0][0][1]= -36; fu[0][0][2]= -990;
 	   fu[0][1][0]=88; fu[0][1][1]= -36; fu[0][1][2]= -990;
 	   fu[0][2][0]=82; fu[0][2][1]= -39; fu[0][2][2]= -988;
@@ -529,7 +525,7 @@ static int motion_detect(int e, int firsttime){
 
  ///K nearest neighbour 
     ///calculating the distance between current buffer and training data
-    for (i=0;i<SAMPLE_SIZE;i++){
+    for (i=0;i<sample_size;i++){
         //comparing training data
         for (j=0;j<BUFFER_SIZE;j++){
             ///calculating distance (training sample i)
@@ -546,9 +542,9 @@ static int motion_detect(int e, int firsttime){
     }
     //diffArray contains all data that we need to sort out
     //lets check our best candidates
-    qsort(diffArray[0],SAMPLE_SIZE,sizeof(int),sort1);
-    qsort(diffArray[1],SAMPLE_SIZE,sizeof(int),sort1);
-    qsort(diffArray[2],SAMPLE_SIZE,sizeof(int),sort1);
+    qsort(diffArray[0],sample_size,sizeof(int),sort1);
+    qsort(diffArray[1],sample_size,sizeof(int),sort1);
+    qsort(diffArray[2],sample_size,sizeof(int),sort1);
     int finalSort[k_nearest];
     //lets find the lowest values
     int kk = 0;
@@ -623,36 +619,43 @@ static gboolean on_roller_button_press_down (ClutterActor *rect, ClutterEvent *e
 }
 
 ///destroy function
-static gboolean on_rect_button_press_exit (ClutterRectangle *rect, ClutterEvent *event, gpointer data){
+void jammer_gohome_button (TangleAction *action, GObject *source, const gchar *trigger, TangleProperties *properties){
+	g_print("Jammer go home!\n");
 	g_source_remove(loop_id);
 	g_object_unref(G_OBJECT(jammerSample0));
 	g_object_unref(G_OBJECT(jammerSample1));
 	g_object_unref(G_OBJECT(jammerSample2));
-	
 	clutter_actor_hide(jammo_get_actor_by_id("jammer-view"));
 	clutter_actor_show(jammo_get_actor_by_id("fullsequencer-view"));
-	return TRUE;
 }
 
-static gboolean on_rect_button_press_play (ClutterRectangle *rect, ClutterEvent *event, gpointer data){
+///mentor function
+void jammer_press_mentor (TangleAction *action, GObject *source, const gchar *trigger, TangleProperties *properties){
+	g_print("Jammer Mentor!\n");
+}
+
+void jammer_press_play (TangleAction *action, GObject *source, const gchar *trigger, TangleProperties *properties){
+	g_print("Jammer play!\n");
 	isJammerRecording = FALSE;
 	isJammerPlaying = FALSE;
 	jammo_sequencer_stop(jammer_sequencer);
 	jammo_sequencer_play(jammer_sequencer);
-	return TRUE;
 }
 
-static gboolean on_rect_button_press_stop (ClutterRectangle *rect, ClutterEvent *event, gpointer data){
-	isJammerRecording = FALSE;
-	isJammerPlaying = TRUE;
-	jammo_sequencer_stop(jammer_sequencer);
-	return TRUE;
-}
 /*RECORD*/
-static gboolean on_rect_button_press_rec (ClutterRectangle *rect, ClutterEvent *event, gpointer data){
-	isJammerRecording = TRUE;
-	jammo_sequencer_play (JAMMO_SEQUENCER (jammer_sequencer));
-	return TRUE;
+void jammer_press_rec (TangleAction *action, GObject *source, const gchar *trigger, TangleProperties *properties){
+	if (!isJammerRecording){
+	//start recording	
+		isJammerRecording = TRUE;
+		jammo_sequencer_play (JAMMO_SEQUENCER (jammer_sequencer));
+		tangle_button_set_selected(TANGLE_BUTTON(jammo_get_actor_by_id("jammer_rec_button")),TRUE);
+	}else{
+	//stop recording
+		isJammerRecording = FALSE;
+		jammo_sequencer_stop(jammer_sequencer);
+		tangle_button_set_selected(TANGLE_BUTTON(jammo_get_actor_by_id("jammer_rec_button")),FALSE);
+	}
+	
 }
 
 static gboolean timeout_func(gpointer data){ ///this runs at jammerFreq (in millisecs)
@@ -662,7 +665,12 @@ static gboolean timeout_func(gpointer data){ ///this runs at jammerFreq (in mill
 		int x = 0;
 		int y = 0;
 		int z = 0;
-		accel_read(&x, &y, &z);
+		int SENSITIVITY = 350; ///how sensitive jammer is TODO: adjust it to current sound latency
+		int accel_test;	
+		accel_test = accel_read(&x, &y, &z);	
+		if (accel_test != 0){
+			//g_print ("No accelerometer present\n");
+		}
 		if (jammerCounter<=BUFFER_SIZE){
 			motionBuffer[BUFFER_SIZE-jammerCounter][0]  =  x;
 			motionBuffer[BUFFER_SIZE-jammerCounter][1]  =  y;
@@ -725,7 +733,7 @@ static void init_jammerinstr(ClutterActor *btnSet){
 	instr[6].isMelodic = TRUE;
 	instr[7].id = 7;
 	g_strlcpy(instr[7].avatarfile, "jammer_xylophone.png", 25);
-	g_strlcpy(instr[7].folder, "xylos", 5);	
+	g_strlcpy(instr[7].folder, "xylo", 5);	
 	instr[7].isMelodic = TRUE;
 	//init images
 	int posx = 0;
@@ -827,12 +835,9 @@ static void preview_note(ClutterActor *key){
 	char *file;
 	file = g_strdup_printf("%s%s/%s_%s.ogg", JAMMERSOUNDPATH,instr[selectedKitNum].folder, instr[selectedKitNum].folder,keyName);
 	previewSample = jammo_sample_new_from_file_with_sequencer(file, jammer_sequencer);
-	//jammo_sample_play(previewSample);
-	//jammo_editing_track_add_sample(jammer_editing_track, previewSample, jammo_sequencer_get_position(jammer_sequencer));
 }
 
 /*play a white key*/
-/*TODO: something is bugged here -- need to clear it*/
 
 static gboolean white_key_pressed (ClutterActor *rect, ClutterEvent *event, gpointer data){
 	int pos;
@@ -960,78 +965,19 @@ static void create_octave(ClutterActor *octSet, gchar *octavenum){
 void 
 start_jammer ()
 {
-	
 	//init clutter
 	ClutterActor *stage;
-	stage = tangle_widget_new(); //TODO: define this and all other (clutter_texture_new_from_file) on jammer-view.json!
+	stage = tangle_widget_new(); //TODO: define this and all other (clutter_texture_new_from_file) on jammer-view.json! --moved some to json
 
 	//init jammer
+	g_print("starting jammer\n");
 	isJammerPlaying = TRUE;
 	isJammerRecording = FALSE;
-	jammer_sequencer = jammo_sequencer_new ();
-	jammer_editing_track = jammo_editing_track_new_fixed_duration (68010648440); //is this correct?
+	jammer_sequencer = JAMMO_SEQUENCER(jammo_get_object_by_id("fullsequencer-the-sequencer"));
+	jammer_editing_track = jammo_editing_track_new(); 
 	jammo_sequencer_add_track (jammer_sequencer, JAMMO_TRACK (jammer_editing_track));
-	/* Add backgrounds */
-	/*main bg*/
-	ClutterActor *bg1 = clutter_texture_new_from_file(g_build_filename(JAMMERIMGPATH, "jammerbackground.png", NULL), NULL);
-	clutter_actor_set_size (bg1, 640, 480);
-	clutter_actor_set_position (bg1, 0, 0);
-	clutter_container_add_actor (CLUTTER_CONTAINER (stage), bg1);
-	clutter_actor_set_reactive (bg1, FALSE);
-	/*roller bg*/	
-	ClutterActor *bg3 = clutter_texture_new_from_file(g_build_filename(JAMMERIMGPATH, "jammerroller.png", NULL), NULL);
-	clutter_actor_set_size (bg3, 483, 480);
-	clutter_actor_set_position (bg3, 0, 0);
-	clutter_container_add_actor (CLUTTER_CONTAINER (stage), bg3);
-	clutter_actor_set_reactive (bg3, FALSE);
-	/*buttons bg*/
-	ClutterActor *bg2 = clutter_texture_new_from_file(g_build_filename(JAMMERIMGPATH, "jammerbuttonbackground.png", NULL), NULL);
-	clutter_actor_set_size (bg2, 400, 480);
-	clutter_actor_set_position (bg2, 450, 0);
-	clutter_container_add_actor (CLUTTER_CONTAINER (stage), bg2);
-	clutter_actor_set_reactive (bg2, FALSE);
-	/*add buttons controls*/	
-	/* Clutter group with buttons */	
-	ClutterActor *btnSet1 = clutter_group_new();
-	clutter_actor_set_size (btnSet1, 90, 480);
-	clutter_actor_set_position (btnSet1, 490, 0);
-	clutter_container_add_actor (CLUTTER_CONTAINER (stage), btnSet1);
-	clutter_actor_set_reactive (btnSet1, TRUE);
-	/*Play button*/
-	ClutterActor *playBtn = clutter_texture_new_from_file(g_build_filename(JAMMERIMGPATH, "jammer_button_play.png", NULL), NULL);
-	clutter_actor_set_size (playBtn, 86, 86);
-	clutter_actor_set_position (playBtn, 0, 390);
-	clutter_container_add_actor (CLUTTER_CONTAINER (btnSet1),playBtn);
-	clutter_actor_set_reactive (playBtn, TRUE);
-	g_signal_connect (playBtn, "button-press-event", G_CALLBACK (on_rect_button_press_play), NULL);
-	/*Stop button*/
-	ClutterActor *stopBtn = clutter_texture_new_from_file(g_build_filename(JAMMERIMGPATH, "jammer_button_stop.png", NULL), NULL);
-	clutter_actor_set_size (stopBtn, 86, 86);
-	clutter_actor_set_position (stopBtn, 0, 290);
-	clutter_container_add_actor (CLUTTER_CONTAINER (btnSet1),stopBtn);
-	clutter_actor_set_reactive (stopBtn, TRUE);
-	g_signal_connect (stopBtn, "button-press-event", G_CALLBACK (on_rect_button_press_stop), NULL);
-	/*Record button*/
-	ClutterActor *recBtn = clutter_texture_new_from_file(g_build_filename(JAMMERIMGPATH, "jammer_button_rec.png", NULL), NULL);
-	clutter_actor_set_size (recBtn, 86, 86);
-	clutter_actor_set_position (recBtn, 0, 190);
-	clutter_container_add_actor (CLUTTER_CONTAINER (btnSet1),recBtn);
-	clutter_actor_set_reactive (recBtn, TRUE);
-	g_signal_connect (recBtn, "button-press-event", G_CALLBACK (on_rect_button_press_rec), NULL);
-	/*Mentor button*/
-	ClutterActor *mentorBtn = clutter_texture_new_from_file(g_build_filename(JAMMERIMGPATH, "jammer_button_mentor.png", NULL), NULL);
-	clutter_actor_set_size (mentorBtn, 86, 86);
-	clutter_actor_set_position (mentorBtn, 0, 90);
-	clutter_container_add_actor (CLUTTER_CONTAINER (btnSet1),mentorBtn);
-	clutter_actor_set_reactive (mentorBtn, TRUE);
-	/*Exit button*/
-	ClutterActor *exitBtn = clutter_texture_new_from_file(g_build_filename(JAMMERIMGPATH, "jammer_button_home.png", NULL), NULL);
-	clutter_actor_set_size (exitBtn, 86, 86);
-	clutter_actor_set_position (exitBtn, 0,0);
-	clutter_container_add_actor (CLUTTER_CONTAINER (btnSet1),exitBtn);
-	g_signal_connect (exitBtn, "button-press-event", G_CALLBACK (on_rect_button_press_exit), NULL);
-	clutter_actor_set_reactive (exitBtn, TRUE);
-	/*End of button group btnSet1*/
+	guint jammerFreq = 250; ///how often jammer reads values and calcs TODO: adjust it to current sound latency
+
 	/*Roller group (btnSet2)*/
 	ClutterActor *btnSet2 = clutter_group_new();
 	clutter_actor_set_size (btnSet2, 200, 280);
@@ -1121,6 +1067,7 @@ start_jammer ()
 	clutter_actor_hide_all(btnSet4);
 	/*End of button group btnSet4*/
 	//////setting up jammer vars
+	g_print("motionBuffer starting\n");
 	int i, j;	
 	for (i=0;i < BUFFER_SIZE; i++){
 		for (j=0;j<3;j++){
@@ -1128,8 +1075,9 @@ start_jammer ()
 		}
 	}
 	///
+	g_print("loop starting\n");
  	loop_id = g_timeout_add(jammerFreq,timeout_func, NULL); 
-	printf("show jammer\n");
+	g_print("show jammer\n");
 	clutter_actor_show(stage);
 	tangle_widget_add(TANGLE_WIDGET(jammo_get_actor_by_id("jammer-view")),stage,NULL);
 }
