@@ -50,50 +50,10 @@ When sequencer starts: it calls load_state_from_file(load_only_backingtrack=TRUE
 JammoSequencer* static_sequencer;
 JammoMetronomeTrack* static_metronome_track;
 
+static void use_backing_track_duration(void);
 static void on_duration_notify(GObject* object, GParamSpec* pspec, gpointer track);
 
-/*
-Each jammo-sample-button has loop-id.
-First digit tells type of loop.
 
-Will return NULL, if anything goeas wrong.
-
-This function might be usefull for networking play (make it non-static)
-*/
-
-static ClutterActor* sequencer_give_sample_button_for_this_id(guint id){
-	guint id_; //Id without first digit
-	gchar* type;
-	if (id>=100 && id <200){
-		type="rhytmical";
-		id_=id-100;
-	} else if (id>=200 && id <300) {
-		type="melodical";
-		id_=id-200;
-	} else if (id>=300 && id <400) {
-		type="harmonical";
-		id_=id-300;
-	}	else if (id>=400 && id <500) {
-		type="effect";
-		id_=id-400;
-	} else {
-		return NULL;
-	}
-
-	gchar* name;
-	name = g_strdup_printf("%s_sample_%d", type,id_);
-
-	JammoSampleButton* sb = JAMMO_SAMPLE_BUTTON(jammo_get_actor_by_id(name)); //clone this!
-	g_free(name);
-	//It is unique, we can't return it.  We make clone of it.
-	ClutterActor* sample_button = NULL;
-	
-	if (sb) {
-		sample_button = jammo_sample_button_new_from_files(jammo_sample_button_get_image_filename(sb),jammo_sample_button_get_sample_filename(sb));
-		jammo_sample_button_set_loop_id(JAMMO_SAMPLE_BUTTON(sample_button),jammo_sample_button_get_loop_id(sb));
-	}
-	return sample_button;  //If sb was NULL, we will return sample_button=NULL.
-}
 
 static void load_state_from_file(gchar* filename, gboolean load_only_backingtrack) {
 
@@ -227,7 +187,12 @@ if (load_only_backingtrack){
 
 						track = JAMMO_TRACK(jammo_backing_track_new(backing_track_filename));
 						// Create other tracks after the duration of the backing track is known.
-						g_signal_connect(track, "notify::duration", G_CALLBACK(on_duration_notify), NULL);
+						
+						if (jammo_track_get_duration(track) == JAMMO_DURATION_INVALID) {
+							g_signal_connect(track, "notify::duration", G_CALLBACK(on_duration_notify), NULL);
+						} else {
+							use_backing_track_duration();
+						}
 						track_view=sequencer_track_view_add_backing_track(track, muted,volume);
 					}
 					printf("Ending looking for BackingTrack\n");
@@ -311,7 +276,7 @@ if (load_only_backingtrack){
 								slot =  json_node_get_int (sub_node);
 								printf("slot: '%d'\n",slot);
 							}
-							ClutterActor* sample_button=sequencer_give_sample_button_for_this_id(loop_id);
+							ClutterActor* sample_button=sequencer_loop_give_sample_button_for_this_id(loop_id);
 							if (sample_button==NULL)
 								printf("Loading loop-id '%d' from file: sample_button==NULL, can't add to track.\n",loop_id);
 							else
@@ -422,10 +387,7 @@ gboolean sequencer_change_to_bottom_view (TangleActor *actor, gpointer data) {
 	return TRUE;
 }
 
-
-
-static void on_duration_notify(GObject* object, GParamSpec* pspec, gpointer none) {
-
+static void use_backing_track_duration(void) {
 	//Now we know duration of backing-track, which is also duration of Sequencer
 	//so we can tune width of area. (needed for cursor e.g.)
 	sequencer_track_view_tune_width();
@@ -433,6 +395,10 @@ static void on_duration_notify(GObject* object, GParamSpec* pspec, gpointer none
 
 	//continue loading
 	load_state_from_file(inputFilename,FALSE);
+}
+
+static void on_duration_notify(GObject* object, GParamSpec* pspec, gpointer none) {
+	use_backing_track_duration();
 
 	// Do not call this function ever again!
 	g_signal_handlers_disconnect_by_func(object, G_CALLBACK(on_duration_notify), NULL);
