@@ -209,6 +209,11 @@ gboolean sequencer_drag_begin(TangleDropAction* drop_action, TangleDragAction* d
 }
 
 
+static int length_of_rhythms=0;
+static int length_of_melodics=0;
+static int length_of_harmonics=0;
+static int length_of_effects=0;
+
 typedef struct {
 	const gchar* image;
 	const gchar* sound;
@@ -266,9 +271,19 @@ static samplebutton_tuple effects[] = {
 	{NULL,NULL}
 };
 
-static void add_sample_buttons(ClutterActor* looper, samplebutton_tuple table[]) {
+
+/*
+loop_type:
+100=rhythms
+200=melodics
+300=harmonics
+400=effects
+
+returns number of this type of sample_buttons
+*/
+static int add_sample_buttons(ClutterActor* looper, samplebutton_tuple table[], int loop_type) {
 	samplebutton_tuple new_button=table[0];
-	int i=0;
+	int counter=0;
 	while(new_button.image){
 		ClutterActor* sample_button;
 		gchar* full_image = tangle_lookup_filename(new_button.image);
@@ -279,16 +294,19 @@ static void add_sample_buttons(ClutterActor* looper, samplebutton_tuple table[])
 		jammo_sample_button_set_image_filename(JAMMO_SAMPLE_BUTTON(sample_button),full_image);
 		jammo_sample_button_set_sample_filename(JAMMO_SAMPLE_BUTTON(sample_button), full_sound);
 
+		jammo_sample_button_set_loop_id(JAMMO_SAMPLE_BUTTON(sample_button), counter+loop_type);
 		g_free(full_image);
 		g_free(full_sound);
 
 		tangle_widget_add(TANGLE_WIDGET(looper),sample_button,NULL);
-		i++;
-		new_button=table[i];
+		counter++;
+		new_button=table[counter];
 	}
+	return counter;
 }
 
 
+
 void sequencer_loop_tune_wheels() {
 	//Static
 	rhytmical_sample_looper  =  jammo_get_actor_by_id("fullsequencer-loop-rhytmical-wheel-scroller");
@@ -296,13 +314,67 @@ void sequencer_loop_tune_wheels() {
 	harmonical_sample_looper =  jammo_get_actor_by_id("fullsequencer-loop-harmonical-wheel-scroller");
 	effect_sample_looper     =  jammo_get_actor_by_id("fullsequencer-loop-effect-wheel-scroller");
 
-	add_sample_buttons(rhytmical_sample_looper,rhythms);
-	add_sample_buttons(melodical_sample_looper,melodics);
-	add_sample_buttons(harmonical_sample_looper,harmonics);
-	add_sample_buttons(effect_sample_looper,effects);
+	length_of_rhythms = add_sample_buttons(rhytmical_sample_looper,rhythms,100);
+	length_of_melodics = add_sample_buttons(melodical_sample_looper,melodics,200);
+	length_of_harmonics = add_sample_buttons(harmonical_sample_looper,harmonics,300);
+	length_of_effects = add_sample_buttons(effect_sample_looper,effects,400);
 
 	fine_tune_wheel(rhytmical_sample_looper);
 	fine_tune_wheel(melodical_sample_looper);
 	fine_tune_wheel(harmonical_sample_looper);
 	fine_tune_wheel(effect_sample_looper);
 }
+
+
+
+/*
+Each jammo-sample-button has loop-id.
+First digit tells type of loop.
+
+Will return NULL, if anything goes wrong.
+
+*/
+ClutterActor* sequencer_loop_give_sample_button_for_this_id(guint id){
+	samplebutton_tuple* asked_table;
+	int length_of_asked;
+	guint id_; //Id without first digit
+	//gchar* type;  //TODO: use this
+	if (id>=100 && id <200){
+		asked_table=rhythms;
+		length_of_asked=length_of_rhythms;
+		id_=id-100;
+	} else if (id>=200 && id <300) {
+		asked_table=melodics;
+		length_of_asked=length_of_melodics;
+		id_=id-200;
+	} else if (id>=300 && id <400) {
+		asked_table=harmonics;
+		length_of_asked=length_of_harmonics;
+		id_=id-300;
+	}	else if (id>=400 && id <500) {
+		asked_table=effects;
+		length_of_asked=length_of_effects;
+		id_=id-400;
+	} else {
+		return NULL;
+	}
+
+	if (id_>length_of_asked)
+		return NULL;
+
+	ClutterActor* sample_button;
+	samplebutton_tuple new_button=asked_table[id_];
+	gchar* full_image = tangle_lookup_filename(new_button.image);
+	gchar* full_sound = g_strdup_printf("%s/%s", DATA_DIR,new_button.sound);
+	//printf("new_sample: '%s', '%s'\n",full_image,full_sound);
+	sample_button = jammo_sample_button_new(); //TODO: jammo_sample_button_new_with_type
+	//g_object_set(sample_button,"sequencer", jammo_get_object_by_id("fullsequencer-the-sequencer"),NULL);
+	jammo_sample_button_set_image_filename(JAMMO_SAMPLE_BUTTON(sample_button),full_image);
+	jammo_sample_button_set_sample_filename(JAMMO_SAMPLE_BUTTON(sample_button), full_sound);
+
+	jammo_sample_button_set_loop_id(JAMMO_SAMPLE_BUTTON(sample_button), id);
+	g_free(full_image);
+	g_free(full_sound);
+
+	return sample_button;
+}
