@@ -31,6 +31,7 @@ And then sequencer_track_view_add_with_type(sequencerTrackViewTYpe)
 #include "instrument_gui.h"
 #include "jammer_view.h"
 
+#include "../../cem/cem.h"
 static int width_of_slot = 40;
 static gfloat track_height = 50.0;
 
@@ -39,10 +40,6 @@ static gfloat track_height = 50.0;
 //We get these as parameters
 static int number_of_slots = -1;
 
-
-static SequencerTrackView *track_views[6] = {NULL};
-static gint tracks_in_use = 0;
-
 static gboolean pressed_sequencer_button_mute (TangleButton *tanglebutton, gpointer user_data);
 static gboolean pressed_sequencer_button_volume (TangleButton *tanglebutton, gpointer user_data);
 static gboolean pressed_sequencer_button_track_label (TangleButton *tanglebutton, gpointer data);
@@ -117,28 +114,28 @@ static SequencerTrackView *sequencer_track_view_new(ClutterActor *label,
 	return view;
 }
 
-#define Y_OFFSET 48
+
 /* Adds STV into array & container and positions it.
  */
 static void sequencer_track_view_add(SequencerTrackView *track_view) {
-	track_views[tracks_in_use] = track_view;
-
 	//Add this tracks control_panel (volume buttons etc)
-	clutter_container_add_actor(CLUTTER_CONTAINER(jammo_get_actor_by_id("fullsequencer-track-control-panel")), track_view->control_panel);
-	clutter_actor_set_y(track_view->control_panel, track_height * tracks_in_use + Y_OFFSET);
+	ClutterActor* panel_container = jammo_get_actor_by_id("fullsequencer-track-control-panel");
+	clutter_container_add_actor(CLUTTER_CONTAINER(panel_container), track_view->control_panel);
 
 	//Add track to container
 	ClutterActor* track_container = jammo_get_actor_by_id("fullsequencer-container-for-tracks");
 	clutter_container_add_actor(CLUTTER_CONTAINER(track_container), track_view->track_view);
-	clutter_actor_set_x(track_view->track_view, clutter_actor_get_x(track_view->track_view)+1);  //unless left border is not visible
-	clutter_actor_set_y(track_view->track_view, track_height * tracks_in_use + Y_OFFSET +1);  //unless bottom border is not visible
+	//clutter_actor_set_x(track_view->track_view, clutter_actor_get_x(track_view->track_view)+1);  //unless left border is not visible
+	//clutter_actor_set_y(track_view->track_view, track_height * tracks_in_use + Y_OFFSET +1);  //unless bottom border is not visible
 
-	//Raise container's and scroller's height
-	clutter_actor_set_height(track_container,clutter_actor_get_height(track_container)+track_height);
+	//Raise cursor's height
+	//cursor_texture is rectangle. cursor_indicator is png-image
 	ClutterActor* texture_of_cursor = jammo_get_actor_by_id("fullsequencer_cursor_texture");
-	clutter_actor_set_height(texture_of_cursor, clutter_actor_get_height(track_container) + Y_OFFSET);
-
-	tracks_in_use++;
+	ClutterActor* indicator_of_cursor = jammo_get_actor_by_id("fullsequencer_cursor_indicator");
+	if (texture_of_cursor && indicator_of_cursor)
+	clutter_actor_set_height(texture_of_cursor,
+     clutter_actor_get_height(track_container) -
+     clutter_actor_get_height(indicator_of_cursor));
 }
 
 
@@ -156,6 +153,7 @@ ClutterActor* sequencer_track_view_add_backing_track(JammoTrack* track, gboolean
      clutter_texture_new_from_file(name_of_label_button, NULL));  /* interactive TODO*/
 
 	track_view_actor = tangle_widget_new();
+	// clutter_actor_set_height(track_view_actor, track_height);
 	g_object_set_data (G_OBJECT(track_view_actor),"track",track);
 	jammo_sequencer_add_track(sequencer, JAMMO_TRACK(track));
 	sequencer_track_view = sequencer_track_view_new(label, track_view_actor, BACKING_TRACK_VIEW, muted,volume);
@@ -256,6 +254,7 @@ ClutterActor* sequencer_track_view_add_with_type(gint track_view_type, gboolean
 
 
 		track_view_actor = tangle_widget_new();
+		// clutter_actor_set_height(track_view_actor, track_height);
 		g_object_set_data (G_OBJECT(track_view_actor),"track",track);
 		//TODO: set size and some visualization.
 		}
@@ -359,7 +358,7 @@ static gboolean pressed_sequencer_button_mute (TangleButton *tanglebutton, gpoin
 This syncs scrollers offset to tracks volume.
 */
 gboolean sequencer_volumebar_used (ClutterActor *scroll_action, gpointer none){
-	printf("sequencer_volumebar_used\n");
+	//printf("sequencer_volumebar_used\n");
 	if (!last_pressed_volume_button)
 		return FALSE;
 
@@ -369,13 +368,14 @@ gboolean sequencer_volumebar_used (ClutterActor *scroll_action, gpointer none){
 	gfloat offset,not_used;
 	tangle_scroll_action_get_offsets(TANGLE_SCROLL_ACTION(scroll_action), &not_used,&offset);
 
-	printf("height %f, offset :%f\n",height, offset);
-
 	JammoPlayingTrack* jammotrack = g_object_get_data(G_OBJECT(volume_scroller),"track");
 
 	gfloat new_volume = offset/height; //This is between [0...1]
 	jammo_playing_track_set_volume(jammotrack,new_volume);
-	//printf("new volume:%f\n\n",new_volume);
+
+	gchar* message = g_strdup_printf("Volume changed to %f",new_volume);
+	cem_add_to_log(message,LOG_USER_ACTION);
+	g_free(message);
 
 	ClutterActor* container = tangle_button_get_normal_background_actor(last_pressed_volume_button);
 	ClutterActor* nub = tangle_widget_get_nth_child(TANGLE_WIDGET(container),0);
@@ -515,7 +515,8 @@ void fullsequencer_home_clicked (TangleButton* tanglebutton, gpointer none){
 	gchar* meta_data = g_strdup_printf
 	("\"pitch\" : \"%s\",\n\"tempo\" : %d,\n",jammo_sequencer_get_pitch(sequencer),jammo_sequencer_get_tempo(sequencer));
 
-	save_composition("7-12/", jammo_get_actor_by_id("fullsequencer-container-for-tracks"),meta_data);
+	//save composition will return filename, but we are not interested in
+	g_free(save_composition("7-12/", jammo_get_actor_by_id("fullsequencer-container-for-tracks"),meta_data));
 	g_free(meta_data);
 	clutter_actor_show(jammo_get_actor_by_id("startmenu-view"));
 }
@@ -549,6 +550,7 @@ void sequencer_track_view_tune_width() {
 	gfloat width_of_area = number_of_slots*width_of_slot;
 	ClutterActor* cursor;
 	cursor = jammo_get_actor_by_id("fullsequencer_cursor");
-	clutter_actor_set_size(cursor, width_of_area, 80.0); //width is important, height is not used
+	if (cursor)
+		clutter_actor_set_size(cursor, width_of_area, 80.0); //width is important, height is not used
 }
 
