@@ -43,6 +43,28 @@ ClutterActor* jammo_note_button_new_without_events() {
 	return note;
 }
 
+static void release_handle(GObject* object, GParamSpec* param_spec, gpointer user_data) {
+	//printf("note_button: release_handle\n");
+	GstClockTime new_stop_time;
+	gfloat new_width;
+	gfloat x;
+	guint64 slot_duration;
+	gfloat slot_width;
+
+	JammoNoteButton* note_button = JAMMO_NOTE_BUTTON(clutter_actor_get_parent(CLUTTER_ACTOR(object)));
+	ClutterActor* parent = clutter_actor_get_parent(CLUTTER_ACTOR(note_button));
+
+	new_width=clutter_actor_get_width(CLUTTER_ACTOR(note_button));
+	x=clutter_actor_get_x(CLUTTER_ACTOR(note_button));
+	g_object_get(parent,"slot-duration", &slot_duration, "slot-width", &slot_width, NULL);
+
+	new_stop_time = (x+new_width) / slot_width * slot_duration;
+	//printf("new_width=%f   , x=%f   , slot_duration %llu  , slot_width=%f \n",new_width,x,slot_duration,slot_width);
+	//printf("new_stop_time =%llu \n",new_stop_time);
+	note_button->priv->stop_event->timestamp = new_stop_time;
+}
+
+
 /*
 width,height
 and start+stop events
@@ -84,12 +106,14 @@ ClutterActor* jammo_note_button_new(gfloat width, gfloat height, JammoMidiEvent*
 	clutter_actor_add_action(handle, action);
 	clutter_actor_set_reactive(handle, TRUE);
 
+	g_signal_connect (handle, "button-release-event", G_CALLBACK (release_handle),NULL);
 	return note_itself;
 }
 
 
 
 static void on_drag_end(ClutterDragAction* action, ClutterActor* actor, gfloat event_x, gfloat event_y, ClutterModifierType modifiers, gpointer user_data) {
+	//printf("note_button: on_drag_end\n");
 	JammoNoteButton* note_button;
 	ClutterActor* parent;
 	
@@ -112,7 +136,7 @@ static void jammo_note_button_constructed(GObject* object) {
 
 	tangle_widget_set_prefer_background_size(TANGLE_WIDGET(note_button), TRUE);
 
-	g_signal_connect(note_button, "clicked", G_CALLBACK(on_clicked), NULL);
+	g_signal_connect(note_button, "button-press-event", G_CALLBACK(on_clicked), NULL);
 }
 
 static void jammo_note_button_set_property(GObject* object, guint prop_id, const GValue* value, GParamSpec* pspec) {
@@ -209,6 +233,7 @@ static void jammo_note_button_init(JammoNoteButton* note_button) {
 
 
 static gboolean on_clicked(TangleButton* button, gpointer user_data) {
+	//printf("note_button: on_clicked\n");
 	JammoNoteButton* note_button;
 	note_button = JAMMO_NOTE_BUTTON(button);
 
@@ -224,6 +249,18 @@ static gboolean on_clicked(TangleButton* button, gpointer user_data) {
 	}
 	printf("duration of this note-button: %f s\n",((long long unsigned)(stop-start)*1.0)/1000000000LLU);
 
+	//If track is in eraser-mode, remove clicked note.
+	ClutterActor* parent = clutter_actor_get_parent(CLUTTER_ACTOR(note_button));
+	if (JAMMO_IS_MIDITRACK_VIEW(parent)) {
+		if (jammo_miditrack_view_get_eraser_mode(JAMMO_MIDITRACK_VIEW(parent))) {
+				clutter_container_remove_actor(CLUTTER_CONTAINER(parent), CLUTTER_ACTOR(note_button));
+				return TRUE;
+		}
+	}
+	else {
+		printf("parent of note-button was not miditrack-view\n");
+	}
+
 	return FALSE;
 }
 
