@@ -63,6 +63,7 @@ GType jammo_sample_type_get_type(void) {
 
 static guint signals[LAST_SIGNAL] = { 0 };
 
+static void on_drag_begin(ClutterDragAction* action, ClutterActor* actor, gfloat event_x, gfloat event_y, ClutterModifierType modifiers, gpointer user_data);
 static void on_drag_end(ClutterDragAction* action, ClutterActor* actor, gfloat event_x, gfloat event_y, ClutterModifierType modifiers, gpointer user_data);
 static gboolean on_clicked(TangleButton* button, gpointer user_data);
 static void on_size_change(ClutterTexture* texture, gint width, gint height, gpointer user_data);
@@ -231,6 +232,7 @@ static void jammo_sample_button_constructed(GObject* object) {
 	
 	sample_button->priv->drag_action = tangle_drag_action_new();
 	g_signal_connect(sample_button->priv->drag_action, "drag-end", G_CALLBACK(on_drag_end), object);
+	g_signal_connect(sample_button->priv->drag_action, "drag-begin", G_CALLBACK(on_drag_begin), object);
 	clutter_actor_add_action(CLUTTER_ACTOR(object), sample_button->priv->drag_action);
 	
 	tangle_widget_set_prefer_background_size(TANGLE_WIDGET(object), TRUE);
@@ -472,6 +474,10 @@ static void jammo_sample_button_init(JammoSampleButton* sample_button) {
 	sample_button->priv = G_TYPE_INSTANCE_GET_PRIVATE(sample_button, JAMMO_TYPE_SAMPLE_BUTTON, JammoSampleButtonPrivate);
 }
 
+static void on_drag_begin(ClutterDragAction* action, ClutterActor* actor, gfloat event_x, gfloat event_y, ClutterModifierType modifiers, gpointer user_data) {
+	jammo_sample_get_duration(JAMMO_SAMPLE_BUTTON(user_data)->priv->sample);
+}
+
 static void on_drag_end(ClutterDragAction* action, ClutterActor* actor, gfloat event_x, gfloat event_y, ClutterModifierType modifiers, gpointer user_data) {
 	ClutterActor* parent;
 	
