@@ -11,6 +11,7 @@
 #include "jammo-track-view.h"
 #include "jammo-sample-button.h"
 #include "../meam/jammo-sample.h"
+#include "../meam/jammo-meam.h"
 #include "../gems/gems.h"
 G_DEFINE_TYPE(JammoTrackView, jammo_track_view, TANGLE_TYPE_WIDGET);
 
@@ -105,7 +106,8 @@ static void on_sample_duration_notify(GObject* object, GParamSpec* pspec, gpoint
 	tangle_widget_set_background_color(TANGLE_WIDGET(sample_button), &track_view->priv->sample_color);
 
 	tangle_widget_add(TANGLE_WIDGET(track_view), CLUTTER_ACTOR(sample_button), NULL);
-	g_signal_handlers_disconnect_by_func(object, G_CALLBACK(on_sample_duration_notify), user_data);
+	if (object)
+		g_signal_handlers_disconnect_by_func(object, G_CALLBACK(on_sample_duration_notify), user_data);
 }
 
 
@@ -118,8 +120,13 @@ void jammo_track_view_add_jammo_sample_button(JammoTrackView* track_view, JammoS
 	TangleVault* vault;
 
 	vault = tangle_vault_new(3, JAMMO_TYPE_SAMPLE_BUTTON, sample_button, JAMMO_TYPE_TRACK_VIEW, track_view, G_TYPE_UINT, slot);
-	tangle_signal_connect_vault(jammo_sample_button_get_sample(JAMMO_SAMPLE_BUTTON(sample_button)),
+	if (jammo_sample_get_duration(jammo_sample_button_get_sample(sample_button))==JAMMO_DURATION_INVALID) {
+		tangle_signal_connect_vault(jammo_sample_button_get_sample(JAMMO_SAMPLE_BUTTON(sample_button)),
            "notify::duration", G_CALLBACK(on_sample_duration_notify), vault);
+	}
+	else {
+		on_sample_duration_notify(NULL,NULL,vault);
+	}
 }
 
 /*
