@@ -217,10 +217,18 @@ int main(int argc, char** argv) {
 	GObject* object;
 	ClutterActor* actor;
 	ClutterColor black = { 0, 0, 0, 255 };
-	gchar* application_path;
-	const gchar* application_name;
+	gchar* application_name;
+	const gchar* duration_cache_filename;
 
-	jammo_meam_init(&argc, &argv);
+	//Name of binary
+	application_name = g_path_get_basename(argv[0]);
+	if (!strcmp(application_name, "jammo7_12") || (argc>=2 && strcmp(argv[1],"sequencer")==0)) {
+		duration_cache_filename = "jammo7_12.duration_cache";
+	} else {
+		duration_cache_filename = "jammo3_6.duration_cache";
+	}
+
+	jammo_meam_init(&argc, &argv, duration_cache_filename);
 	jammo_chum_init(&argc, &argv);
 	
 	/* GEMS initialization and profile manager test */
@@ -244,9 +252,6 @@ int main(int argc, char** argv) {
 
 	srand (time (NULL)); //We will use rand()
 
-	//Name of binary
-	application_path = g_strdup(argv[0]);
-	application_name = basename(application_path);
 
 
 #ifdef N900
@@ -372,7 +377,7 @@ int main(int argc, char** argv) {
 		}
 	}
 
-	g_free(application_path);
+	g_free(application_name);
 printf("start clutter-main\n");
 	clutter_main();
 
