@@ -36,10 +36,10 @@ on_rect_button_press_exit (ClutterRectangle *rect, ClutterEvent *event, gpointer
 void button_exit_set(ClutterActor *stage)
 {
 
-	  gchar* filename1="exit.png";
+	  gchar* filename1="skip.png";
 	  gchar* path1 = g_build_filename (pg_directory_path, filename1, NULL);
 	  ClutterActor *exit_btn = clutter_texture_new_from_file (path1, NULL);
-	  clutter_actor_set_size (exit_btn, 87, 120);
+	  clutter_actor_set_size (exit_btn, 86, 86);
 	  clutter_actor_set_position (exit_btn, 700, 20);
 
 	  clutter_actor_show (exit_btn);
@@ -66,7 +66,7 @@ on_rect_button_press_pool (ClutterRectangle *rect, ClutterEvent *event, ClutterA
   return FALSE;
 }
 */
-void button_action_set(ClutterActor *stage)
+/*void button_action_set(ClutterActor *stage)
 {
 
 	  gchar* filename2="option.png";
@@ -80,8 +80,8 @@ void button_action_set(ClutterActor *stage)
 	  clutter_actor_set_reactive (pool_btn, TRUE);
 	  //g_signal_connect (pool_btn, "button-press-event", G_CALLBACK (on_rect_button_press_pool), myKnot1);
 
-}
-void button_ok_set(ClutterActor *stage)
+} */
+/*void button_ok_set(ClutterActor *stage)
 {
 
 	  gchar* filename2="ok.png";
@@ -95,7 +95,7 @@ void button_ok_set(ClutterActor *stage)
 	  clutter_actor_set_reactive (ok_btn, TRUE);
 	  //g_signal_connect (pool_btn, "button-press-event", G_CALLBACK (on_rect_button_press_pool), myKnot1);
 
-}
+}*/
 void button_next_set(ClutterActor *stage)
 {
 
@@ -111,6 +111,7 @@ void button_next_set(ClutterActor *stage)
 	  //g_signal_connect (pool_btn, "button-press-event", G_CALLBACK (on_rect_button_press_pool), myKnot1);
 
 }
+/*
 void button_back_set(ClutterActor *stage)
 {
 
@@ -125,9 +126,9 @@ void button_back_set(ClutterActor *stage)
 	  clutter_actor_set_reactive (back_btn, TRUE);
 	  //g_signal_connect (pool_btn, "button-press-event", G_CALLBACK (on_rect_button_press_pool), myKnot1);
 
-}
+}*/
 
-void button_cancel_set(ClutterActor *stage)
+/*void button_cancel_set(ClutterActor *stage)
 {
 
 	  gchar* filename2="cancel.png";
@@ -142,15 +143,15 @@ void button_cancel_set(ClutterActor *stage)
 	  //g_signal_connect (pool_btn, "button-press-event", G_CALLBACK (on_rect_button_press_pool), myKnot1);
 
 }
-
+*/
 ClutterActor *button_avatar_set(ClutterActor *stage)
 {
 
-	  gchar* filename2="avatar.png";
+	  gchar* filename2="wrong_pass.png";
 	  gchar* path2 = g_build_filename (pg_directory_path, filename2, NULL);
 	  ClutterActor *avatar_btn = clutter_texture_new_from_file (path2, NULL);
-	  clutter_actor_set_size (avatar_btn, 50, 50);
-	  clutter_actor_set_position (avatar_btn, 275, 175);
+	  clutter_actor_set_size (avatar_btn, 85, 91);
+	  clutter_actor_set_position (avatar_btn, 600, 200);
 	  clutter_actor_show (avatar_btn);
 	  clutter_container_add_actor (CLUTTER_CONTAINER (stage), avatar_btn);
 
