@@ -40,9 +40,11 @@
 -user_metadata will be something differencies between 3-6 game and 7-12 game.
  3-6 game contains info about theme_name and variation
  7-12 game contains info about pitch and tempo
+
+ Will return final filename (with fullpath). User must free it.
 */
 
-gboolean save_composition(gchar* to_filename, ClutterActor* sequencer_widget, gchar* user_metadata) {
+gchar* save_composition(gchar* to_filename, ClutterActor* sequencer_widget, gchar* user_metadata) {
 	printf("Saving composition.\n");
 
 	//Generate filename baesd on timestamp
@@ -64,7 +66,7 @@ gboolean save_composition(gchar* to_filename, ClutterActor* sequencer_widget, gc
 
 	ofp = fopen(outputFilename, "w");
 	g_free(outputFilename);
-	g_return_val_if_fail(ofp != NULL, FALSE);
+	g_return_val_if_fail(ofp != NULL, g_strdup_printf("error")); //user want free this
 
 	//'Header'
 	fprintf(ofp,"{\n");
@@ -226,8 +228,9 @@ gboolean save_composition(gchar* to_filename, ClutterActor* sequencer_widget, gc
 
 	//Saving to cupboard
 	gchar* cmd;
-
-	cmd = g_strdup_printf("mv %s/last_composition.json %s/%s%s.json",JAMMO_DIRECTORY,COMPOSITIONS_DIRECTORY,to_filename,timestamp_now);
+	gchar* final_filename;
+	final_filename = g_strdup_printf("%s/%s%s.json",COMPOSITIONS_DIRECTORY,to_filename,timestamp_now);
+	cmd = g_strdup_printf("mv %s/last_composition.json %s",JAMMO_DIRECTORY,final_filename);
 
 	//printf("Executing: '%s'\n",cmd);
 	if (system(cmd))
@@ -235,6 +238,6 @@ gboolean save_composition(gchar* to_filename, ClutterActor* sequencer_widget, gc
 
 	g_free(cmd);
 
-	return TRUE;
+	return final_filename;
 }
 
