@@ -130,42 +130,66 @@ void gems_service_group_handle_current_group(gems_components* data, gems_connect
 	// If same group as ours
 	if(gems_connection_get_32(element,8) == data->service_group->group_info->id)
 	{
-		// If group owner differs from the one in our data - check that group owner (previous) sent this
-		if((gems_connection_get_32(element,12) != data->service_group->group_info->owner) && 
-			(element->profile->id == data->service_group->group_info->owner))
+		// Sent by owner
+		if(element->profile->id == data->service_group->group_info->owner)
 		{
-			// Update owner - it can change when owner decides to quit and assigns ownership to some other user
-			data->service_group->group_info->owner = gems_connection_get_32(element,12);
-			// TODO if we're assigned as owner notify user ?
-		}
+			// If group owner differs from the one in our data
+			if(gems_connection_get_32(element,12) != data->service_group->group_info->owner)
+			{
+				// Update owner - it can change when owner decides to quit and assigns ownership to some other user
+				data->service_group->group_info->owner = gems_connection_get_32(element,12);
+				// TODO if we're assigned as owner notify user ?
+			}
 		
-		// If owner is some other than us
-		if(data->service_group->group_info->owner != gems_profile_manager_get_userid(NULL))
-		{
 			// Update other
 			data->service_group->group_info->type = gems_connection_get_16(element,16);
 			data->service_group->group_info->size = gems_connection_get_16(element,18);
 			data->service_group->group_info->spaces = gems_connection_get_16(element,20);
 			data->service_group->group_info->theme = gems_connection_get_16(element,22);
-		
 			// TODO get group lock type
-			
-			// Get owner of the group
-			gems_connection* element = gems_communication_get_connection_with_userid(data->communication->connections, data->service_group->group_info->owner);
 		
-			msg = gems_create_message_group_management_notify(REQUEST_MEMBERS, 0, 0);
+			// If owner is some other than us - request updated member list
+			if(data->service_group->group_info->owner != gems_profile_manager_get_userid(NULL))
+			{	
+				// Get owner of the group
+				gems_connection* element = gems_communication_get_connection_with_userid(data->communication->connections, data->service_group->group_info->owner);
+		
+				msg = gems_create_message_group_management_notify(REQUEST_MEMBERS, 0, 0);
 			
-			if(element != NULL)
-			{
-				if(gems_communication_write_encrypted_data(JAMMO_PACKET_PRIVATE, element, msg) == FALSE)
+				if(element != NULL)
 				{
-					logerror = g_strdup_printf("gems_service_group_handle_current_group: cannot write REQUEST_MEMBERS to group owner id %u", data->service_group->group_info->owner);
+					if(gems_communication_write_encrypted_data(JAMMO_PACKET_PRIVATE, element, msg) == FALSE)
+					{
+						logerror = g_strdup_printf("gems_service_group_handle_current_group: cannot write REQUEST_MEMBERS to group owner id %u", data->service_group->group_info->owner);
+					}
+				}
+				else logmsg = g_strdup_printf("gems_service_group_handle_current_group: wrote REQUEST_MEMBERS ");
+
+				gems_clear_message(msg);
+			}
+			// We are the new owner (the member list should have been sent by the previous owner before leaving)
+			else
+			{
+				logmsg = g_strdup_printf("gems_service_group_handle_current_group: got group %u ownership from %u", data->service_group->group_info->id, element->profile->id);
+				
+				switch(data->service_group->group_info->own_state)
+				{
+					// We were joining - set to belong in group
+					case JOINING:
+						data->service_group->group_info->own_state = IN_GROUP;
+						break;
+					// We were leaving, set to belong in group and leave again
+					case LEAVING:
+						data->service_group->group_info->own_state = IN_GROUP;
+						gems_group_leave_from_group();
+						break;
+					default:
+						break;
 				}
 			}
-			else logmsg = g_strdup_printf("gems_service_group_handle_current_group: wrote REQUEST_MEMBERS ");
-
-			gems_clear_message(msg);
 		}
+		// Otherwise ignore - group info is updated by owner only
+		else logmsg = g_strdup_printf("gems_service_group_handle_current_group: got CURRENT_GROUP from non-owner (%u, owner: %u)", element->profile->id, data->service_group->group_info->owner);
 	}
 	else
 	{
