@@ -154,6 +154,12 @@ const gchar* jammo_sample_get_filename(JammoSample* sample) {
  * if that information is not available.
  */
 guint64 jammo_sample_get_duration(JammoSample* sample) {
+	if (sample->priv->duration == JAMMO_DURATION_INVALID &&
+	   ((sample->priv->duration = jammo_meam_get_cached_duration(sample->priv->real_filename)) == JAMMO_DURATION_INVALID)) {
+		g_message("No cached duration for '%s', prerolling.", sample->priv->real_filename);
+
+		play_sample(sample, TRUE);
+	}
 	
 	return sample->priv->duration;
 }
@@ -522,6 +528,8 @@ static gboolean preroll_bus_callback(GstBus* bus, GstMessage* message, gpointer
 				     "media-duration", play_data->sample->priv->duration,
 				     NULL);
 			g_object_notify(G_OBJECT(play_data->sample), "duration");
+			
+			jammo_meam_set_cached_duration(play_data->sample->priv->real_filename, play_data->sample->priv->duration);
 		}
 		cleanup = TRUE;
 	} else if (GST_MESSAGE_TYPE(message) == GST_MESSAGE_ERROR) {
@@ -672,8 +680,10 @@ static void initialize_state(JammoSample* sample) {
 			g_object_set(sample->priv->element,
 				     "location", sample->priv->real_filename,
 				     NULL);
-			sample->priv->duration = JAMMO_DURATION_INVALID;
-			play_sample(sample, TRUE);
+			if (sample->priv->duration != JAMMO_DURATION_INVALID) {
+				sample->priv->duration = JAMMO_DURATION_INVALID;
+				g_object_notify(G_OBJECT(sample), "duration");
+			}
 		} else {
 			sample->priv->element = gst_element_factory_make("gnlfilesource", NULL);
 			g_object_set(sample->priv->element,
@@ -686,8 +696,6 @@ static void initialize_state(JammoSample* sample) {
 		        		     "duration", sample->priv->duration,
 					     "media-duration", sample->priv->duration,
 					     NULL);
-			} else {
-				play_sample(sample, TRUE);
 			}
 		}
 	} else {
