@@ -12,7 +12,6 @@
 #include "jammo-meam.h"
 #include "jammo-meam-private.h"
 #include "jammo-pipeline.h"
-#include "jammo-instrument-track.h"
 
 /**
  * SECTION:jammo-sequencer
@@ -47,6 +46,7 @@ enum {
 struct _JammoSequencerPrivate {
 	guint tempo;
 	gchar* pitch;
+	gint64 latency;
 
 	GstElement* pipeline;
 	GstElement* bin;
@@ -77,6 +77,9 @@ static guint signals[LAST_SIGNAL] = { 0 };
 // quality for ogg file created in file mode
 #define OGGQUALITY 0.5
 
+// default latency, will be used if no track requests lower
+#define DEFAULT_LATENCY 80000
+
 /**
  * jammo_sequencer_new:
  *
@@ -266,6 +269,7 @@ JammoTrack* jammo_sequencer_get_track(JammoSequencer* sequencer, guint index) {
  */
 void jammo_sequencer_add_track(JammoSequencer* sequencer, JammoTrack* track) {
 	GstElement* element;
+	gint64 desired_latency;
 	
 	if (g_list_find(sequencer->priv->tracks, track)) {
 		g_warning("A track is already added into a sequencer.");
@@ -293,6 +297,11 @@ void jammo_sequencer_add_track(JammoSequencer* sequencer, JammoTrack* track) {
 			sequencer->priv->ready = FALSE;
 			g_object_notify(G_OBJECT(sequencer), "ready");
 		}
+		desired_latency=_jammo_track_latency_query(track);
+		if (desired_latency>0 && desired_latency<sequencer->priv->latency) {
+			sequencer->priv->latency=desired_latency;
+			jammo_sequencer_set_latency(sequencer, sequencer->priv->latency);
+		}
 	}
 }
 
@@ -424,6 +433,36 @@ gboolean jammo_sequencer_set_output_filename(JammoSequencer* sequencer, const gc
 	return retvalue;
 }
 
+/**
+ * jammo_sequencer_get_latency:
+ * @sequencer: a #JammoSequencer
+ *
+ * Returns the latency of audiosink.
+ *
+ * Return value: latency in us or -1 on error
+ */
+gint64 jammo_sequencer_get_latency(JammoSequencer* sequencer) {
+	if (sequencer->priv->audiosink) {
+		gint64 latency;
+		g_object_get(G_OBJECT(sequencer->priv->audiosink), "buffer-time", &latency, NULL);
+		return latency;
+	}
+	return -1;
+}
+
+/**
+ * jammo_sequencer_set_latency:
+ * @sequencer: a #JammoSequencer
+ * @latency: the requested latency
+ *
+ * Sets the latency of audiosink.
+ */
+void jammo_sequencer_set_latency(JammoSequencer* sequencer, gint64 latency) {
+	if (sequencer->priv->audiosink) {
+		g_object_set(G_OBJECT(sequencer->priv->audiosink), "buffer-time", latency, NULL);
+	}
+}
+
 static void jammo_sequencer_set_property(GObject* object, guint prop_id, const GValue* value, GParamSpec* pspec) {
 	JammoSequencer* sequencer;
 	
@@ -594,6 +633,7 @@ static void jammo_sequencer_init(JammoSequencer* sequencer) {
 
 	sequencer->priv->ready = TRUE;
 	sequencer->priv->tempo = 110;
+	sequencer->priv->latency = DEFAULT_LATENCY;
 
 	sequencer->priv->pipeline = jammo_pipeline_new(NULL);
 	bus = gst_pipeline_get_bus(GST_PIPELINE(sequencer->priv->pipeline));
@@ -701,7 +741,7 @@ static gboolean setup_audiosink(JammoSequencer* sequencer) {
 	
 	if ((sequencer->priv->queue = create_element("queue")) &&
 	    (sequencer->priv->audiosink = create_element("pulsesink"))) {
-	    	g_object_set(sequencer->priv->audiosink, "buffer-time", 800000, NULL);
+	    	g_object_set(sequencer->priv->audiosink, "buffer-time", DEFAULT_LATENCY, NULL);
 		gst_bin_add_many(GST_BIN(sequencer->priv->bin), sequencer->priv->queue, sequencer->priv->audiosink, NULL);
 		if (!gst_element_link_many(sequencer->priv->adder, sequencer->priv->queue, sequencer->priv->audiosink, NULL)) {
 			g_critical("Failed to link pulsesink.");
