@@ -60,4 +60,7 @@ gboolean jammo_sequencer_set_position(JammoSequencer* sequencer, guint64 positio
 const gchar* jammo_sequencer_get_output_filename(JammoSequencer* sequencer);
 gboolean jammo_sequencer_set_output_filename(JammoSequencer* sequencer, const gchar* output_filename);
 
+gint64 jammo_sequencer_get_latency(JammoSequencer* sequencer);
+void jammo_sequencer_set_latency(JammoSequencer* sequencer, gint64 latency);
+
 #endif
