@@ -17,6 +17,9 @@
 // value does not matter but there has to be a reference tempo
 #define DEFAULT_TEMPO 110.0
 
+// desired latency for slider track in us
+#define SLIDER_TRACK_LATENCY 10000
+
 G_DEFINE_TYPE(JammoSliderTrack, jammo_slider_track, JAMMO_TYPE_PLAYING_TRACK);
 
 enum {
@@ -63,6 +66,10 @@ static void jammo_slider_track_set_offline(JammoTrack* track, gboolean offline)
 	jammo_slider_track_set_recording(slider_track, !offline);
 }
 
+static gint64 jammo_slider_track_latency_query(JammoTrack* track) {
+		return SLIDER_TRACK_LATENCY;
+}
+
 static void jammo_slider_track_set_property(GObject* object, guint prop_id, const GValue* value, GParamSpec* pspec) {
 	JammoSliderTrack* slider_track;
 	
@@ -236,6 +243,7 @@ static void jammo_slider_track_class_init(JammoSliderTrackClass* slider_track_cl
 	track_class->set_offline = jammo_slider_track_set_offline;
 	track_class->set_pitch = jammo_slider_track_set_pitch;
 	track_class->set_tempo = jammo_slider_track_set_tempo;
+	track_class->latency_query = jammo_slider_track_latency_query;
 	playing_track_class->setup_playing_element = jammo_slider_track_setup_playing_element;
 	gobject_class->finalize = jammo_slider_track_finalize;
 	gobject_class->dispose = jammo_slider_track_dispose;
