@@ -67,13 +67,13 @@ guint64 jammo_track_get_duration(JammoTrack* track) {
  *
  * Internally used by a #JammoSequencer.
  */
-gboolean _jammo_track_setup_element(JammoTrack* track, GstBin* bin, GstElement* sink_element) {
+gboolean _jammo_track_setup_element(JammoTrack* track, GstPipeline* pipeline, GstBin* bin, GstElement* sink_element) {
 	gboolean retvalue = FALSE;
 	JammoTrackClass* track_class;
 
 	track_class = JAMMO_TRACK_GET_CLASS(track);
 	if (track_class->setup_element) {
-		retvalue = track_class->setup_element(track, bin, sink_element);
+		retvalue = track_class->setup_element(track, pipeline, bin, sink_element);
 	}
 	
 	return retvalue;
@@ -132,6 +132,16 @@ void _jammo_track_set_offline(JammoTrack* track, gboolean offline) {
 	}
 }
 
+gint64 _jammo_track_latency_query(JammoTrack* track) {
+	JammoTrackClass* track_class;
+
+	track_class = JAMMO_TRACK_GET_CLASS(track);
+	if (track_class->latency_query) {
+		return (track_class->latency_query(track));
+	}
+	return -1;
+}
+
 static void jammo_track_get_property(GObject* object, guint prop_id, GValue* value, GParamSpec* pspec) {
         JammoTrack* track;
 
