@@ -36,6 +36,7 @@ struct _JammoTrack {
  * @get_element: virtual function for getting the #GstElement of the track
  * @receive_message: virtual function for receiving a #GstMessage from the backend
  * @set_muted: virtual function for setting muting on and off
+ * @latency_query: virtual function for desired latency query
  */
 struct _JammoTrackClass {
 	GInitiallyUnownedClass parent_class;
@@ -46,6 +47,7 @@ struct _JammoTrackClass {
 	void (*set_tempo)(JammoTrack* track, guint tempo);
 	void (*set_pitch)(JammoTrack* track, const gchar* pitch);
 	void (*set_offline)(JammoTrack* track, gboolean offline);
+	gint64 (*latency_query)(JammoTrack* track);
 };
 
 GType jammo_track_get_type(void);
