@@ -71,7 +71,7 @@ int main(int argc, char** argv) {
 	GError* error = NULL;
 	ClutterActor* actor;
 	
-	jammo_meam_init(&argc, &argv);
+	jammo_meam_init(&argc, &argv, "jammo_test_duration_cache");
 	jammo_chum_init(&argc, &argv);
 	
 	stage = clutter_stage_get_default();
