@@ -40,7 +40,7 @@ int main (int argc, char **argv) {
 	memset(&their_addr, 0, sizeof(struct sockaddr));
 	addr_len = sizeof(struct sockaddr);
 
-  jammo_meam_init (&argc, &argv);
+  jammo_meam_init (&argc, &argv, "jammo_test_duration_cache");
   jammo_chum_init (&argc, &argv);
 
 	if (argc<2){
