@@ -26,7 +26,7 @@ int main(int argc, char** argv) {
 	ClutterActor* texture;
 	ClutterActor* mentor;
 	
-	jammo_meam_init(&argc, &argv);
+	jammo_meam_init(&argc, &argv, "jammo_test_duration_cache");
 	jammo_chum_init(&argc, &argv);
 	
 	stage = clutter_stage_get_default();
