@@ -25,7 +25,7 @@
 
 int main (int argc, char **argv) {
 
-  jammo_meam_init (&argc, &argv);
+  jammo_meam_init (&argc, &argv, "jammo_test_duration_cache");
   jammo_chum_init (&argc, &argv);
 
 	JammoCollaborationPairComposition* collaboration_pair_composition = jammo_collaboration_pair_composition_new();
